@@ -108,8 +108,8 @@ def se_module(inputs, se_ratio=0.25, activation="relu", use_bias=True, name=""):
     se = keras.layers.Conv2D(reduction, kernel_size=1, use_bias=use_bias, kernel_initializer=CONV_KERNEL_INITIALIZER, name=name and name + "1_conv")(se)
     se = activation_by_name(se, activation=activation, name=name)
     se = keras.layers.Conv2D(filters, kernel_size=1, use_bias=use_bias, kernel_initializer=CONV_KERNEL_INITIALIZER, name=name and name + "2_conv")(se)
-    se = keras.layers.Activation("sigmoid")(se)
-    return keras.layers.Multiply()([inputs, se])
+    se = activation_by_name(se, activation="sigmoid", name=name)
+    return keras.layers.Multiply(name=name and name + "out")([inputs, se])
 
 
 def drop_block(inputs, drop_rate=0, name=None):
@@ -142,3 +142,14 @@ def anti_alias_downsample(inputs, kernel_size=3, strides=2, padding="SAME", trai
         depthwise_initializer=anti_alias_downsample_initializer,
         name=name and name + "anti_alias_down",
     )(inputs)
+
+
+def make_divisible(vv, divisor=4, min_value=None):
+    """ Copied from https://github.com/tensorflow/models/blob/master/research/slim/nets/mobilenet/mobilenet.py """
+    if min_value is None:
+        min_value = divisor
+    new_v = max(min_value, int(vv + divisor / 2) // divisor * divisor)
+    # Make sure that round down does not go down by more than 10%.
+    if new_v < 0.9 * vv:
+        new_v += divisor
+    return new_v
